% This script is part of the MUBI Scanner, developed by the
% Ultrasound Systems and Technology Group of the Spanish National 
% Research Council (USTG-ITEFI) and Grupo de Fsica Nuclear, of the
% University Complutense of Madrid (GFN-UCM), Spain.
%
% Contact information: j.camacho@csic.es
%
% This sample Matlab script extract the elements coordinates and the 
% A-Scans from the dataset and plot them in a figure.

clear all;

%Load acquisition parameters
load parametros.mat;

%Variables in parametros.mat file are:
%
% N_elementos   : Number of array elements
% N_rx          : Number of receiver array positions in each fan-beam
% N_tx          : Number of fan-beams
% array_f       : Array center frequency in MHz
% fanbeam_deg   : Fanbeam angle in degrees
% he            : Active elements in emission (1:active, 0: inactive) 
%                 Size = 1 x N_elementos.
% hr            : Active elements in reception (1:active, 0: inactive) 
%                 Size = 1 x N_elementos.
% pitch         : Array pitch in mm
% tacq          : Acquisition time in us
% tdlr_sitau    : Acquisition start instant for each A-Scan in us
%                 Size = N_rx x sum(he) x sum(hr)
% tdlr_w        : Transtit time in water between each emitter-receiver pair
%                 Size = N_rx x sum(he) x sum(hr)
% tsa           : Sampling period in multiples of 25 ns
%                 Example: tsa = 2 -> period = 50 ns 
%                                  -> sampling frequency = 20 MHz.

%----- Correct BUG in he vector ------------------------------
%In these datasets, the last emitting element is 128, not 121
if he(end) == 122
    he(end) = 1;
end
%-------------------------------------------------------------

%Load speed of water
load meas_c.mat

%Variables in meas_c.mat are
%  
% c         : Measured speed of sound in water (mm/us)
% c_date    : Calibration date
% c_hour    : Calibration hour


%Read and paint ...

for i = 1:N_tx %for each fanbeam

    %Load fanbeam file
    file = sprintf('Fan-Beam%02d.mat',i);
    load(file);
    
    %variables in Fan-Beam file are:
    %
    % Ascans_rx     : A-Scan data for all emitter-receiver pairs
    %                 Size = N_tx x sum(he) x sum(hr) x tacq/(0.025*tsa)
    % activos_rx    : Indexes to emitter active elements
    % activos_tx    : Indexes to receiver active elements
    % centros_3     : Coordinates of the emitter array center (mm)
    % centros_4     : Coordinates of the receiver array centers (mm)
    % coordenadas   : Coordinates of the elements (mm)
    %                 Size = N_rx x sum(he) x sum(hr) x 2 x 2
    
    ne = sum(he); %Number of active elements in emission
    nr = sum(hr); %Number of active elements in reception
    
    xe = squeeze(coordenadas(1,:,1,1,1)); %X Coordinates of emitting array
    ye = squeeze(coordenadas(1,:,1,1,2)); %Y Coordinates of emitting array
    
    for j=1:N_rx %For each receiving array position
            
        xr = squeeze(coordenadas(j,1,:,2,1)); %X Coordinates of receiving array
        yr = squeeze(coordenadas(j,1,:,2,2)); %Y Coordinates of receiving array   
              
        %Get and plot each A-Scan
        for k = 1:ne
            for l = 1:nr              
                
                ascan = double(squeeze(Ascans_rx(j,k,l,:))); %Ascan
                t = tdlr_sitau(j,k,l) + [0:length(ascan)-1]*(0.025*tsa); %Time base including acquisition delay
                
                figure(1);
                title(['Fan-Beam ' num2str(i)]);
                xlabel('x (mm)'); ylabel('y (mm)');

                %Plot array elements
                subplot(1,2,1);
                plot(xe,ye,'r.');hold on;
                plot(xr,yr,'b.');
                rectangle('Position',[-95 -95 95*2 95*2],'Curvature',1);
                
                %plot the path between emitter and receiver
                plot([xe(k) xr(l)],[ye(k) yr(l)],'k');        
                axis equal; axis([-100 100 -100 100]);
                hold off;
                
                
                %plot the received signal in percentage
                subplot(1,2,2); 
                plot(t,ascan/32767*100);                
                xlabel('t (us)');
                ylabel('Amplitude (%)');
                axis([t(1) t(end) -100 100])
                drawnow;

            end
        end
    end
    

end 
